@@ -1,13 +1,14 @@
 import gradio as gr
 import numpy as np
 import torch
-from diffusers import ControlNetModel, StableDiffusionControlNetPipeline
+from diffusers import ControlNetModel
+from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.pipeline_stable_diffusion_controlnet_inpaint import StableDiffusionControlNetInpaintPipeline
 from PIL import Image
 from transformers import pipeline
 
 from diffusion_webui.utils.model_list import (
     controlnet_depth_model_list,
-    stable_model_list,
+    stable_inpiant_model_list,
 )
 from diffusion_webui.utils.scheduler_list import (
     SCHEDULER_LIST,
@@ -26,7 +27,7 @@ class StableDiffusionControlInpaintNetDepthGenerator:
             controlnet = ControlNetModel.from_pretrained(
                 controlnet_model_path, torch_dtype=torch.float16
             )
-            self.pipe = StableDiffusionControlNetPipeline.from_pretrained(
+            self.pipe = StableDiffusionControlNetInpaintPipeline.from_pretrained(
                 pretrained_model_name_or_path=stable_model_path,
                 controlnet=controlnet,
                 safety_checker=None,
@@ -39,10 +40,14 @@ class StableDiffusionControlInpaintNetDepthGenerator:
 
         return self.pipe
 
+    def load_image(self, image_path):
+        image = np.array(image_path)
+        image = Image.fromarray(image)
+        return image
+
     def controlnet_inpaint_depth(self, image_path: str):
         depth_estimator = pipeline("depth-estimation")
         image = image_path["image"].convert("RGB").resize((512, 512))
-        image = np.array(image)
         image = depth_estimator(image)["depth"]
         image = np.array(image)
         image = image[:, :, None]
@@ -65,8 +70,13 @@ class StableDiffusionControlInpaintNetDepthGenerator:
         scheduler: str,
         seed_generator: int,
     ):
-
-        image = self.controlnet_inpaint_depth(image_path=image_path)
+        normal_image = image_path["image"].convert("RGB").resize((512, 512))
+        mask_image = image_path["mask"].convert("RGB").resize((512, 512))
+        
+        normal_image = self.load_image(image_path=normal_image)
+        mask_image = self.load_image(image_path=mask_image)
+        
+        control_image = self.controlnet_inpaint_depth(image_path=image_path)
 
         pipe = self.load_model(
             stable_model_path=stable_model_path,
@@ -82,7 +92,10 @@ class StableDiffusionControlInpaintNetDepthGenerator:
 
         output = pipe(
             prompt=prompt,
-            image=image,
+            
+            image=normal_image,
+            mask_image=mask_image,
+            control_image=control_image,
             negative_prompt=negative_prompt,
             num_images_per_prompt=num_images_per_prompt,
             num_inference_steps=num_inference_step,
@@ -118,8 +131,8 @@ class StableDiffusionControlInpaintNetDepthGenerator:
                         with gr.Column():
                             controlnet_depth_inpaint_stable_model_id = (
                                 gr.Dropdown(
-                                    choices=stable_model_list,
-                                    value=stable_model_list[0],
+                                    choices=stable_inpiant_model_list,
+                                    value=stable_inpiant_model_list[0],
                                     label="Stable Model Id",
                                 )
                             )
