@@ -2,11 +2,13 @@ import gradio as gr
 import numpy as np
 import torch
 from controlnet_aux import OpenposeDetector
-from diffusers import ControlNetModel, StableDiffusionControlNetPipeline
+from diffusers import ControlNetModel
+from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.pipeline_stable_diffusion_controlnet_inpaint import StableDiffusionControlNetInpaintPipeline
+from PIL import Image
 
 from diffusion_webui.utils.model_list import (
     controlnet_pose_model_list,
-    stable_model_list,
+    stable_inpiant_model_list,
 )
 from diffusion_webui.utils.scheduler_list import (
     SCHEDULER_LIST,
@@ -26,7 +28,7 @@ class StableDiffusionControlNetInpaintPoseGenerator:
                 controlnet_model_path, torch_dtype=torch.float16
             )
 
-            self.pipe = StableDiffusionControlNetPipeline.from_pretrained(
+            self.pipe = StableDiffusionControlNetInpaintPipeline.from_pretrained(
                 pretrained_model_name_or_path=stable_model_path,
                 controlnet=controlnet,
                 safety_checker=None,
@@ -38,7 +40,12 @@ class StableDiffusionControlNetInpaintPoseGenerator:
         self.pipe.enable_xformers_memory_efficient_attention()
 
         return self.pipe
-
+    
+    def load_image(self, image_path):
+        image = np.array(image_path)
+        image = Image.fromarray(image)
+        return image
+    
     def controlnet_pose_inpaint(self, image_path: str):
         openpose = OpenposeDetector.from_pretrained("lllyasviel/ControlNet")
 
@@ -62,8 +69,13 @@ class StableDiffusionControlNetInpaintPoseGenerator:
         scheduler: str,
         seed_generator: int,
     ):
-
-        image = self.controlnet_pose_inpaint(image_path=image_path)
+        normal_image = image_path["image"].convert("RGB").resize((512, 512))
+        mask_image = image_path["mask"].convert("RGB").resize((512, 512))
+        
+        normal_image = self.load_image(image_path=normal_image)
+        mask_image = self.load_image(image_path=mask_image)
+        
+        controlnet_image = self.controlnet_pose_inpaint(image_path=image_path)
 
         pipe = self.load_model(
             stable_model_path=stable_model_path,
@@ -79,7 +91,9 @@ class StableDiffusionControlNetInpaintPoseGenerator:
 
         output = pipe(
             prompt=prompt,
-            image=image,
+            image=normal_image,
+            mask_image=mask_image,
+            control_image=controlnet_image,
             negative_prompt=negative_prompt,
             num_images_per_prompt=num_images_per_prompt,
             num_inference_steps=num_inference_step,
@@ -115,8 +129,8 @@ class StableDiffusionControlNetInpaintPoseGenerator:
                         with gr.Column():
                             controlnet_pose_inpaint_stable_model_id = (
                                 gr.Dropdown(
-                                    choices=stable_model_list,
-                                    value=stable_model_list[0],
+                                    choices=stable_inpiant_model_list,
+                                    value=stable_inpiant_model_list[0],
                                     label="Stable Model Id",
                                 )
                             )
