@@ -8,7 +8,7 @@ from diffusion_webui.diffusion_models.controlnet.controlnet_hed import (
     StableDiffusionControlNetHEDGenerator,
 )
 from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_canny import (
-    StableDiffusionControlInpaintNetCannyGenerator,
+    StableDiffusionControlNetInpaintCannyGenerator,
 )
 from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_depth import (
     StableDiffusionControlInpaintNetDepthGenerator,
